==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/request/RoleScopeTagRequest.java <==
package odata.msgraph.client.beta.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.CollectionPageNonEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.annotation.Action;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.util.List;
import java.util.Map;

import odata.msgraph.client.beta.entity.RoleScopeTag;
import odata.msgraph.client.beta.entity.RoleScopeTagAutoAssignment;
import odata.msgraph.client.beta.entity.collection.request.RoleScopeTagAutoAssignmentCollectionRequest;
import odata.msgraph.client.beta.schema.SchemaInfo;

@JsonIgnoreType
public class RoleScopeTagRequest extends EntityRequest<RoleScopeTag> {

    public RoleScopeTagRequest(ContextPath contextPath) {
        super(RoleScopeTag.class, contextPath, SchemaInfo.INSTANCE);
    }

    public RoleScopeTagAutoAssignmentCollectionRequest assignments() {
        return new RoleScopeTagAutoAssignmentCollectionRequest(
                        contextPath.addSegment("assignments"));
    }

    public RoleScopeTagAutoAssignmentRequest assignments(String id) {
        return new RoleScopeTagAutoAssignmentRequest(contextPath.addSegment("assignments").addKeys(new NameValue(id.toString())));
    }

    @Action(name = "assign")
    @JsonIgnore
    public CollectionPageNonEntityRequest<RoleScopeTagAutoAssignment> assign(List<RoleScopeTagAutoAssignment> assignments) {
        Map<String, TypedObject> _parameters = ParameterMap
            .put("assignments", "Collection(microsoft.graph.roleScopeTagAutoAssignment)", assignments)
            .build();
        return CollectionPageNonEntityRequest.forAction(this.contextPath.addActionOrFunctionSegment("microsoft.graph.assign"), RoleScopeTagAutoAssignment.class, _parameters, odata.msgraph.client.beta.schema.SchemaInfo.INSTANCE);
    }

}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/entity/request/RoleScopeTagRequest.java <==
package odata.msgraph.client.beta.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.CollectionPageNonEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.annotation.Action;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Object;
import java.lang.String;
import java.util.List;
import java.util.Map;
import java.util.Optional;

import odata.msgraph.client.beta.entity.RoleScopeTag;
import odata.msgraph.client.beta.entity.RoleScopeTagAutoAssignment;
import odata.msgraph.client.beta.entity.collection.request.RoleScopeTagAutoAssignmentCollectionRequest;

@JsonIgnoreType
public class RoleScopeTagRequest extends EntityRequest<RoleScopeTag> {

    public RoleScopeTagRequest(ContextPath contextPath, Optional<Object> value) {
        super(RoleScopeTag.class, contextPath, value, false);
    }

    public RoleScopeTagAutoAssignmentRequest assignments(String id) {
        return new RoleScopeTagAutoAssignmentRequest(contextPath.addSegment("assignments").addKeys(new NameValue(id, String.class)), Optional.empty());
    }

    public RoleScopeTagAutoAssignmentCollectionRequest assignments() {
        return new RoleScopeTagAutoAssignmentCollectionRequest(
                        contextPath.addSegment("assignments"), Optional.empty());
    }

    @Action(name = "assign")
    @JsonIgnore
    public CollectionPageNonEntityRequest<RoleScopeTagAutoAssignment> assign(List<RoleScopeTagAutoAssignment> assignments) {
        Map<String, TypedObject> _parameters = ParameterMap
            .put("assignments", "Collection(microsoft.graph.roleScopeTagAutoAssignment)", assignments)
            .build();
        return CollectionPageNonEntityRequest.forAction(this.contextPath.addActionOrFunctionSegment("microsoft.graph.assign"), RoleScopeTagAutoAssignment.class, _parameters);
    }

}
